# Break a dependency cycle: apache-commons-jexl -> jacoco -> maven-reporting-api
#   -> maven-doxia -> apache-commons-configuration -> apache-commons-jexl
%bcond_with bootstrap

Name:           apache-commons-jexl
Version:        3.4.0
Release:        %mkrel 2
Summary:        Java Expression Language
Group:          Development/Java
License:        Apache-2.0
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch
URL:            https://commons.apache.org/proper/commons-jexl/
VCS:            https://github.com/apache/commons-jexl
Source0:        https://archive.apache.org/dist/commons/jexl/source/commons-jexl-%{version}-src.tar.gz
Source1:        https://archive.apache.org/dist/commons/jexl/source/commons-jexl-%{version}-src.tar.gz.asc
Source2:        https://downloads.apache.org/commons/KEYS

# Use the codehaus version of javacc-maven-plugin, which is available from
# Fedora, instead of ph-javacc-maven-plugin, which is not.
Patch0:         %{name}-javacc.patch
# Fix malformed javadoc constructs
Patch1:         %{name}-javadoc.patch

BuildRequires:  gnupg2
BuildRequires:  maven-local
BuildRequires:  mvn(com.google.code.gson:gson)
BuildRequires:  mvn(commons-logging:commons-logging)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)
BuildRequires:  mvn(org.apache.maven.plugins:maven-assembly-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-compiler-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-jar-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-surefire-plugin)
BuildRequires:  mvn(org.apiguardian:apiguardian-api)
BuildRequires:  mvn(org.codehaus.mojo:javacc-maven-plugin)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-params)

%if %{without bootstrap}
BuildRequires:  mvn(org.jacoco:jacoco-maven-plugin)
%endif

%description
JEXL is a library intended to facilitate the implementation of scripting
features in applications and frameworks written in Java.  JEXL
implements an Expression Language based on some extensions to the JSTL
Expression Language supporting most of the constructs seen in shell
script or ECMAScript.  Its goal is to expose scripting features usable
by technical operatives or consultants working with enterprise
platforms.

%javadoc_package

%prep
%{gpgverify} --data=%{SOURCE0} --signature=%{SOURCE1} --keyring=%{SOURCE2}
%autosetup -n commons-jexl3-%{version}-src -p1

# Remove workaround for fixed JavaCC bug.
# The workaround now causes build failure.
%pom_remove_plugin :maven-antrun-plugin

# Work around @{argLine} expansion failure
%pom_xpath_remove //pom:argLine

# Not needed for RPM builds
%pom_xpath_remove //pom:reporting
%pom_remove_plugin :animal-sniffer-maven-plugin
%pom_remove_plugin :apache-rat-plugin
%pom_remove_plugin :japicmp-maven-plugin
%pom_remove_plugin :maven-checkstyle-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-pmd-plugin
%pom_remove_plugin :maven-scm-publish-plugin
%pom_remove_plugin :spotbugs-maven-plugin

# Not available in Fedora
%pom_remove_dep :concurrentlinkedhashmap-lru
rm src/test/java/org/apache/commons/jexl3/{CachePerformanceTest,ConcurrentCache}.java

# Needed for the tests
%pom_add_dep org.apiguardian:apiguardian-api:1.1.2:test

# Break a dependency cycle in bootstrap mode
%if %{with bootstrap}
%pom_remove_plugin :jacoco-maven-plugin
%endif

%build
%mvn_build

%install
%mvn_install

%files -f .mfiles
%doc RELEASE-NOTES.txt
%license LICENSE.txt NOTICE.txt


%changelog
* Mon Jun 24 2024 daviddavid <daviddavid> 3.4.0-2.mga10
+ Revision: 2076475
- rebuild for missing pkgs

* Thu Jun 06 2024 daviddavid <daviddavid> 3.4.0-1.mga10
+ Revision: 2070297
- Version 3.4.0
- Add patch to fix malformed javadoc constructs

* Wed May 22 2024 ns80 <ns80> 3.3-1.mga10
+ Revision: 2066189
- new version 3.3 for java 21
+ neoclust <neoclust>
- Not used anymore

* Wed Feb 12 2020 umeabot <umeabot> 2.1.1-21.mga8
+ Revision: 1501320
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 2.1.1-20.mga7
+ Revision: 1277609
- Mageia 7 Mass Rebuild

* Wed Oct 04 2017 daviddavid <daviddavid> 2.1.1-19.mga7
+ Revision: 1168497
- Port to current javacc (sync with fc27)

* Wed May 17 2017 neoclust <neoclust> 2.1.1-17.mga6
+ Revision: 1102461
- Add missing build-requires

* Wed Mar 02 2016 neoclust <neoclust> 2.1.1-16.mga6
+ Revision: 982094
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 2.1.1-15.mga6
+ Revision: 975434
- First rebuild of the java stack
- sync package apache-commons-jexl with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.1.1-11.mga5
+ Revision: 746018
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.1.1-10.mga5
+ Revision: 677811
- Mageia 5 Mass Rebuild

* Tue Nov 26 2013 dmorgan <dmorgan> 2.1.1-9.mga4
+ Revision: 553588
- Fix BuildRequires
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Thu Jul 11 2013 dmorgan <dmorgan> 2.1.1-7.mga4
+ Revision: 453198
- Build with xmvn
- New version
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 28 2011 dmorgan <dmorgan> 2.0.1-6.mga2
+ Revision: 188460
- Packaging fixes
- New maven macro for depmaps (include a compat depmap) #745118

* Wed Apr 27 2011 dmorgan <dmorgan> 2.0.1-5.mga1
+ Revision: 92237
- Rebuild after bootstrapping
- imported package apache-commons-jexl


* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec 6 2010 Orion Poplawski <orion@cora.nwra.com> - 2.0.1-3
- Use BR apache-commons-parent

* Tue Jul 13 2010 Orion Poplawski <orion@cora.nwra.com> - 2.0.1-2
- Add license to javadoc package

* Wed May 26 2010 Orion Poplawski <orion@cora.nwra.com> - 2.0.1-1
- Update to 2.0.1
- Require Java 1.6 or greater
- Drop language level patch
- Add patch to remove bsf-api 3.0 dependency from pom.xml as this is provided
  by Java 1.6
- Fix depmap group id

* Sat Jan 9 2010 Orion Poplawski <orion@cora.nwra.com> - 1.1-3
- Drop gcj support
- Fix javadoc group
- Bump java levels in pom.xml

* Thu Jan 7 2010 Orion Poplawski <orion@cora.nwra.com> - 1.1-2
- Rename to apache-commons-jexl

* Tue Oct 27 2009 Orion Poplawski <orion@cora.nwra.com> - 1.1-1
- Initial Fedora Package
